selectiontools.VerticalMoment
=============================

.. abjad-lineage:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment

.. autoclass:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.attack_count
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.components
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_duration
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_spanners
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_vertical_moment_at
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.governors
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.leaves
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.measures
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.next_vertical_moment
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.notes
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.offset
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_components
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_leaves
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_measures
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_notes
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.previous_vertical_moment
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_components
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_leaves
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_notes
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__add__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__contains__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__eq__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__format__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__getitem__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__hash__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__len__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__ne__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__radd__
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__repr__

Bases
-----

- :py:class:`selectiontools.SimultaneousSelection <abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection>`

- :py:class:`selectiontools.Selection <abjad.tools.selectiontools.Selection.Selection>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.attack_count
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.components
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.governors
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.leaves
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.measures
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.next_vertical_moment
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.notes
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.offset
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_components
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_leaves
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_measures
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.overlap_notes
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.previous_vertical_moment
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_components
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_leaves
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.start_notes
   :noindex:

Methods
-------

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_duration
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_spanners
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.get_vertical_moment_at
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__format__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__hash__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.VerticalMoment.VerticalMoment.__repr__
   :noindex:
